@@ -770,7 +770,51 @@ def _rand_option(options):
     except IndexError:
         return _rand_option(options)
 
+def female_first_last_name():
+    '''
+        Generate a random female first and last name
 
+        ----------
+
+        Return {tuple}
+        ----------------------
+        A tuple (first,last)
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-05-2022 11:48:42
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: female_first_last_name
+        * @xxx [06-05-2022 11:49:20]: documentation for female_first_last_name
+    '''
+
+    
+    fake = faker()
+    return (fake.first_name_female(), fake.last_name())
+
+def male_first_last_name():
+    '''
+        Generate a random male first and last name
+
+        ----------
+
+        Return {tuple}
+        ----------------------
+        A tuple (first,last)
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-05-2022 11:48:42
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: male_first_last_name
+        * @xxx [06-05-2022 11:49:20]: documentation for male_first_last_name
+    '''    
+    fake = faker()
+    return (fake.first_name_male(), fake.last_name())
 
 def gender()->str:
     '''
